@@ -42,7 +42,8 @@ import {
   get_kernel_name,
   set_requirements,
   set_requirement_lock,
-  set_thoth_configuration
+  set_thoth_configuration,
+  delete_key_from_notebook_metadata
 } from "../notebook"
 
 import { Advise } from "../types/thoth";
@@ -375,12 +376,6 @@ export class DependenciesManagementUI extends React.Component<IProps, IState> {
 
       const deleted_packages = this.state.deleted_packages
 
-      // Check if there are any deleted packages and relock in that case
-      if ( _.size( deleted_packages ) > 0 ) {
-        this.lock_using_thoth()
-        return
-      }
-
       const notebookMetadataRequirements = this.state.requirements
       const added_packages = this.state.packages
       console.log("added_packages", added_packages)
@@ -404,6 +399,44 @@ export class DependenciesManagementUI extends React.Component<IProps, IState> {
         }
       })
 
+      // Check if there are any deleted packages
+      if ( _.size( deleted_packages ) > 0 ) {
+
+        if (  _.size(total_packages ) > 0 ) {
+          // If there are any deleted packages and others relock with resolution engine
+
+          this.lock_using_thoth()
+          return
+        }
+
+        else {
+          // If there are any deleted packages and no other packages, then free requirements, requirements_lock and thoth.yaml
+          delete_key_from_notebook_metadata( this.props.panel, "requirements" )
+          delete_key_from_notebook_metadata( this.props.panel, "requirements_lock" )
+          delete_key_from_notebook_metadata( this.props.panel, "thoth_config" )
+
+          // Save all changes to disk.
+          this.props.panel.context.save()
+
+          var emptyRequirements: Requirements = {
+            packages: total_packages,
+            requires: notebookMetadataRequirements.requires,
+            sources: [new Source()]
+          }
+
+          this.changeUIstate(
+            "initial",
+            new_packages,
+            this.state.initial_packages,
+            this.state.installed_packages,
+            {},
+            emptyRequirements,
+            this.state.kernel_name
+          )
+        }
+
+      }
+
       // Check if there are packages saved, otherwise go to failed notification message
       if ( _.size(total_packages ) > 0 ) {
 
@@ -471,7 +504,7 @@ export class DependenciesManagementUI extends React.Component<IProps, IState> {
         var emptyRequirements: Requirements = {
           packages: total_packages,
           requires: notebookMetadataRequirements.requires,
-          sources: notebookMetadataRequirements.sources
+          sources: [new Source()]
         }
 
         console.log("Requirements are: ", emptyRequirements)
@@ -529,12 +562,19 @@ export class DependenciesManagementUI extends React.Component<IProps, IState> {
 
     }
 
-    async store_dependencies_on_disk (requirements: Requirements, requirements_lock: RequirementsLock) {
+    async store_dependencies_on_disk (
+        requirements: Requirements,
+        requirements_lock: RequirementsLock,
+        path_to_store: string,
+        using_home_path_base: boolean
+      ) {
         // TODO: Requested from the user (in this case it is to install them)
         const store_message: string = await store_dependencies(
           this.state.kernel_name,
           JSON.stringify(requirements),
-          JSON.stringify(requirements_lock)
+          JSON.stringify(requirements_lock),
+          path_to_store,
+          using_home_path_base
         );
 
         console.log("Store message", store_message);
@@ -593,6 +633,15 @@ export class DependenciesManagementUI extends React.Component<IProps, IState> {
 
       const thothConfig: ThothConfig = await this.createConfig();
 
+      // If the endpoint cannot be reached or there are issues with thamos config creation
+
+      if (_.isUndefined(thothConfig)) {
+
+        console.log("Thoth config is undefined")
+
+        this.lock_using_pipenv()
+      }
+
       const runtime_environments: RuntimeEnvornment[] = thothConfig.runtime_environments
 
       const runtime_environment: RuntimeEnvornment = runtime_environments[0]
@@ -622,6 +671,13 @@ export class DependenciesManagementUI extends React.Component<IProps, IState> {
           set_requirement_lock( this.props.panel , advise.requirement_lock )
           set_thoth_configuration( this.props.panel , thothConfig )
 
+          await this.store_dependencies_on_disk(
+            advise.requirements,
+            advise.requirement_lock,
+            'overlays',
+            false
+          )
+
           this.changeUIstate(
             "installing_requirements",
             {},
@@ -675,6 +731,13 @@ export class DependenciesManagementUI extends React.Component<IProps, IState> {
 
           set_requirement_lock( this.props.panel , result.requirements_lock )
 
+          await this.store_dependencies_on_disk(
+            notebookMetadataRequirements,
+            result.requirements_lock,
+            'overlays',
+            false
+          )
+
           this.changeUIstate(
             "installing_requirements",
             {},
