@@ -16,6 +16,8 @@ import { URLExt } from '@jupyterlab/coreutils';
 
 import { ServerConnection } from '@jupyterlab/services';
 
+export const THOTH_JUPYTER_INTEGRATION_API_BASE_NAME = "jupyterlab_requirements";
+
 /**
  * Call the API extension
  *
@@ -35,7 +37,7 @@ export async function requestAPI<T>(
   // build the full request URL
   const requestUrl = URLExt.join(
     settings.baseUrl,
-    'jupyterlab-requirements',
+    THOTH_JUPYTER_INTEGRATION_API_BASE_NAME,
     endPoint
   );
 
